"""Google Workspace MCP Server.

Connect Claude to Google Workspace APIs including Gmail, Calendar, Drive, Docs, and Tasks.
"""

from gworkspace_mcp.__version__ import __version__

__all__ = ["__version__"]
